@@ -3,16 +3,17 @@
  *    Title: dsarch.c
  *   Author: Zaihua Ji, zji@ucar.edu
  *     Date: 2024-01-30
- *  Purpose: C wrapper to setuid for dsarch python scripts
+ *  Purpose: C wrapper to setuid for a common effective user to
+ *           run dsarch python scripts
  *
  * Instruction:
+ *    after python -m pip install rda_python_dsarch
+ *    cd ../rda_python_dsarch/
+ *    cp dsarch.c $ENVHOME/bin/
+ *    cd $ENVHOME/bin/
+ *    sudo -u CommonUser gcc -o dsarch $ENVHOME/bin/dsarch.c
+ *    sudo -u CommonUser chmod 4750 dsarch
  *
- *    dsarch.c $LOCHOME/bin/dsarch.c
- *    cd $LOCHOME/bin/
- *    gcc -o dsarch dsarch.c
- *    chmod 4750 dsarch
- *
- *    $LOCHOME: /usr/local/decs On DECS machines, and /ncar/rda/setuid on DAV
  *    $ENVHOME: /glade/u/home/rdadata/rdamsenv on DECS machines, and
  *              /glade/work/zji/conda-envs/pg-rda on DAV
  *
@@ -23,25 +24,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <libgen.h>
 
 /* main program */
 int main(int argc, char *argv[]) {
-   char *name;
    char prog[128];
-   char pext[] = ".py";
+   char file[] = __FILE__;
 
-   strcpy(prog, getenv("ENVHOME"));
-   strcat(prog, "/bin/");
-   name = strrchr(argv[0], '/');
-   if(name == (char *)NULL) {
-      strcat(prog, argv[0]);
-   } else {
-      strcat(prog, ++name);
-   }
-   name = strrchr(prog, '.');
-   if(name == (char *)NULL || strcmp(name, pext) != 0) {
-      strcat(prog, pext);
-   }
+   strcpy(prog, dirname(file));
+   strcat(prog, "/dsarch.py");
 
    /* call Python script */
    execv(prog, argv);
